package dotsec.samples;

import java.io.*;
import java.security.*;
import java.security.spec.*;
import java.security.cert.*;
import java.security.cert.Certificate;

 /**
  *  <p>Class representing a simple PKCS#12 object with 1 key and 
  *  1 cert chain (containing 2 certificates)
  *
  *  <p>Also there are a couple of static utility methods  for reading/writing
  *     data of various formats
  *
  */

public class P12Wrapper
{
   private PrivateKey key;
   private X509Certificate[] certChain;
 
   public P12Wrapper(String file, String pwd, String alias) throws Exception
   {
     KeyStore ks = KeyStore.getInstance("PKCS12");
     ks.load(new FileInputStream(file), pwd.toCharArray());
     this.key = (PrivateKey) ks.getKey(alias, pwd.toCharArray());
     Certificate[] chain = ks.getCertificateChain(alias);
     this.certChain = new X509Certificate[chain.length];
     for (int i=0; i < chain.length; i++)
       certChain[i] = (X509Certificate) chain[i];
   }

   public X509Certificate[] getCertChain()
   {
     return this.certChain;
   }

   public PrivateKey getKey() throws Exception
   {
     return this.key;
   }


   public static void writeISToFile(InputStream in, String fileName) throws IOException
   {
     FileOutputStream fos = new FileOutputStream(fileName);
     byte[] buf = new byte[128];
     int rd = 0;
     while (true)
     {
       rd = in.read(buf);
       if (rd == -1)
         break;
       fos.write(buf, 0, rd);
     }
     fos.close();
   }

   public static X509Certificate loadCert(String file) throws Exception
   {
      CertificateFactory fact = CertificateFactory.getInstance("X.509");
      FileInputStream fis = new FileInputStream(file);
      return (X509Certificate)fact.generateCertificate(fis);
   }


}
